@@ -344,13 +344,7 @@ class MyHandler(BaseHTTPRequestHandler):
                            'metadata': metadata})
         
 
-        # Set the response headers for json
-        self.send_response(200)
-        self.send_header('Access-Control-Allow-Origin', '*')
-        self.send_header('Access-Control-Allow-Headers',
-                             'X-Request, X-Requested-With')
-        self.send_header('Content-type', 'application/json')
-        self.end_headers()
+
 
         # Write response
         self.wfile.write(data)
@@ -369,7 +363,13 @@ class MyHandler(BaseHTTPRequestHandler):
         if uri.path == '/forward_model.json':
 
         
-            
+            # Set the response headers for json
+            self.send_response(200)
+            self.send_header('Access-Control-Allow-Origin', '*')
+            self.send_header('Access-Control-Allow-Headers',
+                             'X-Request, X-Requested-With')
+            self.send_header('Content-Type', 'application/json')
+            self.end_headers()
             
             content_len = int(self.headers.getheader('content-length'))
             raw_json = self.rfile.read(content_len)
